<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>ConkyCustomizeDialog</name>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="56"/>
        <source>Customize Conky - %1</source>
        <translation>Prilagodi Conky -%1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="77"/>
        <source>Launch</source>
        <translation>Izvedi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="81"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Start</source>
        <translation>Začni</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="83"/>
        <source>Undo</source>
        <translation>Razveljavi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="106"/>
        <location filename="../src/conkycustomizedialog.cpp" line="186"/>
        <source>Colors</source>
        <translation>Barve</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Default</source>
        <translation>Privzeto</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color0</source>
        <translation>Barva0</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color1</source>
        <translation>Barva1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color2</source>
        <translation>Barva2</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color3</source>
        <translation>Barva3</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color4</source>
        <translation>Barva4</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color5</source>
        <translation>Barva5</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color6</source>
        <translation>Barva6</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color7</source>
        <translation>Barva7</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color8</source>
        <translation>Barva8</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color9</source>
        <translation>Barva9</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="193"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="337"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="713"/>
        <source>Select Color</source>
        <translation>Izbira barve</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="819"/>
        <source>Permission Denied</source>
        <translation>Zavrnitev dovoljenja</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="820"/>
        <source>Cannot write to file: %1
Insufficient permissions.</source>
        <translation>Ne morem pisati v datoteko: %1
Nimate dovolj pravic.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="830"/>
        <source>Write Error</source>
        <translation>Napaka pri zapisovanju</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="830"/>
        <source>Cannot write to file: %1</source>
        <translation>Ne morem pisati v datoteko: %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="921"/>
        <source>Backup Config File</source>
        <translation>Varnostna kopija nastavitvene datoteke</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="921"/>
        <source>Do you want to preserve the original file?</source>
        <translation>Ali bi radi ohranili izvirno datoteko?</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="945"/>
        <source>Backed Up Config File</source>
        <translation>Varnostna kopija nastavitvene datoteke</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="946"/>
        <source>The original configuration was backed up to %1</source>
        <translation>Izvirna nastavitvena datoteka je bila shranjena kot %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="948"/>
        <source>Backup Failed</source>
        <translation>Varnostno kopiranje ni uspelo</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="948"/>
        <source>Failed to create a backup file.</source>
        <translation>Ni bilo mogoče ustvariti varnostne kopije</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1029"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1032"/>
        <source>Restore Failed</source>
        <translation>Obnovitev ni uspela</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1029"/>
        <source>Failed to restore from backup file.</source>
        <translation>Obnovitev iz varnostne kopije ni bila uspešna</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1032"/>
        <source>Backup file does not exist.</source>
        <translation>Varnostna kopija ne obstaja</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1384"/>
        <source>Position</source>
        <translation>Položaj</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1391"/>
        <source>Alignment</source>
        <translation>Poravnava</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1396"/>
        <source>Top Left</source>
        <translation>Zgoraj levo</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1397"/>
        <source>Top Right</source>
        <translation>Zgoraj desno</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1398"/>
        <source>Top Middle</source>
        <translation>Zgoraj sredina</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1399"/>
        <source>Bottom Left</source>
        <translation>Spodaj levo</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1400"/>
        <source>Bottom Right</source>
        <translation>Spodaj desno</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1401"/>
        <source>Bottom Middle</source>
        <translation>Spodaj sredina</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1402"/>
        <source>Middle Left</source>
        <translation>Sredina levo</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1403"/>
        <source>Middle Right</source>
        <translation>Sredina desno</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1404"/>
        <source>Middle Middle</source>
        <translation>Sredina sredina</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1409"/>
        <source>Horizontal Gap</source>
        <translation>Vodoravni razmik</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1410"/>
        <source>[GAP_X] Horizontal distance from window border (in pixels)</source>
        <translation>[GAP_X] Vodoravni odmik od roba okna (v pikslih)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1422"/>
        <source>Vertical Gap</source>
        <translation>Navpični razmik</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1423"/>
        <source>[GAP_Y] Vertical distance from window border (in pixels)</source>
        <translation>[GAP_X] Navpični odmik od roba okna (v pikslih)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1435"/>
        <source>Desktop</source>
        <translation>Namizje</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1438"/>
        <source>Desktop 1</source>
        <translation>Namizje 1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1439"/>
        <source>All Desktops</source>
        <translation>Vsa namizja</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1451"/>
        <source>Location</source>
        <translation>Lokacija</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1463"/>
        <source>Width should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation>Širina naj bo večja od vsebine okna,
sicer nastavitev nima učinka</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1467"/>
        <source>Minimum Width</source>
        <translation>Najmanjša širina</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1482"/>
        <source>Height should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation>Višina naj bo večja od vsebine okna,
sicer nastavitev nima učinka</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1484"/>
        <source>Minimum Height</source>
        <translation>Najmanjša višina</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1498"/>
        <source>Increases the window height by adding empty lines at the end of the Conky config file</source>
        <translation>Višino okna lahko povečate z dodajanjem praznih vrstic na konec Conky nastavitvene datoteke</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1499"/>
        <source>Height Padding</source>
        <translation>Odmik višine</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1514"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1527"/>
        <source>Transparency Type</source>
        <translation>Vsrata prosojnosti</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1532"/>
        <source>Opaque</source>
        <translation>Neprosojno</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1533"/>
        <source>Transparent</source>
        <translation>Prosojno</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1534"/>
        <source>Pseudo-Transparent</source>
        <translation>Psevdo-prosojno</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1535"/>
        <source>Semi-Transparent</source>
        <translation>Pol-prosojno</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1540"/>
        <source>Opacity (%)</source>
        <translation>Neprosojnost (%)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1541"/>
        <source>Window Opacity

0 = Fully Transparent, 100 = Fully Opaque</source>
        <translation>Neprosojnost okna

0=popolnoma prosojno, 100=neprosojno</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1555"/>
        <source>Background Color</source>
        <translation>Barva ozadja</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1560"/>
        <source>Choose Color</source>
        <translation>Izbira barve</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1580"/>
        <source>Setting Type to &quot;Transparent&quot; will make the whole window transparent (including any images). Use &quot;Pseudo-Transparent&quot; if you want the images to be opaque.</source>
        <translation>Nastvitev vrste na &quot;Prosojno&quot; bo naredilo okno popolnoma prosojno (tudi slike). Uporabite &quot;Psevdo-prosojno&quot;, če želite, da slike ostanejo neprosojne.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1590"/>
        <source>Setting Type to &quot;Pseudo-Transparent&quot; will make the window transparent but the window will have a shadow. The shadow can be disabled by configuring your window manager.</source>
        <translation>Nastavitev vrste na &quot;Psevdo-prosojno&quot; bo naredilo okno prosojno, okno pa bo imelo senco. Senco lahko odpravite v upravljalniku oken.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1601"/>
        <source>Transparency</source>
        <translation>Prosojnost</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1612"/>
        <source>Date Format</source>
        <translation>Oblika datuma</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1615"/>
        <source>Day</source>
        <translation>Dan</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1617"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1628"/>
        <source>Long</source>
        <translation>Dolgi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1618"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1629"/>
        <source>Short</source>
        <translation>Kratek</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1619"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Skrajšano ime, npr. TO</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1626"/>
        <source>Month</source>
        <translation>Mesec</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1630"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Skrajšano ime, npr. okt</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1649"/>
        <source>Time Format</source>
        <translation>Oblika časa</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1656"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1661"/>
        <source>12 Hour</source>
        <translation>12 ur</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1662"/>
        <source>24 Hour</source>
        <translation>24 ur</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1663"/>
        <source>auto</source>
        <translation>samodejno</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1678"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Datum &amp;&amp; ura</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1691"/>
        <source>Interface</source>
        <translation>Vmesnik</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1699"/>
        <source>WiFi</source>
        <translation>WiFi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1702"/>
        <source>WiFi Network</source>
        <translation>WiFi omrežje</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1705"/>
        <source>LAN</source>
        <translation>LAN</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1708"/>
        <source>Wired LAN Network</source>
        <translation>Ožičeno LAN omrežje</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1722"/>
        <source>Network</source>
        <translation>Omrežje</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="2037"/>
        <source>Select Background Color</source>
        <translation>Izbira barve ozadja</translation>
    </message>
</context>
<context>
    <name>ConkyItemWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="64"/>
        <source>Running</source>
        <translation>Se izvaja</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="64"/>
        <source>Stopped</source>
        <translation>Zaustavljeno</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="138"/>
        <source>Autostart</source>
        <translation>Samodejni zagon</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="140"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="143"/>
        <source>Customize</source>
        <translation>Prilagajanje</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="148"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="177"/>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="180"/>
        <source>Start</source>
        <translation>Začni</translation>
    </message>
</context>
<context>
    <name>ConkyListWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="344"/>
        <source>Total: 0 conkies</source>
        <translation>Skupaj conkijevj: 0</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="598"/>
        <source>Total: %1 conkies</source>
        <translation>Skupaj conkijevj: %1</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="601"/>
        <source>Showing: %1 of %2 conkies</source>
        <translation>Prikazano conkijev: %1 od %2</translation>
    </message>
</context>
<context>
    <name>ConkyPreviewWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="550"/>
        <source>No Conky Selected</source>
        <translation>Noben conky ni izbran</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="552"/>
        <source>Select a conky from the list to see its preview</source>
        <translation>S seznama izberite conky za predogled</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="571"/>
        <source>Preview image could not be loaded</source>
        <translation>Slike za predogled ni bilo mogoče naložiti</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="574"/>
        <source>No preview image available</source>
        <translation>Ni slike za predogled</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="58"/>
        <location filename="../src/mainwindow.cpp" line="849"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <source>About this application</source>
        <translation>O tem programu</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="248"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="255"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="270"/>
        <source>Quit application</source>
        <translation>Zapri aplikacijo</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="268"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="158"/>
        <source>Loading Conky configurations...</source>
        <translation>Nalaganje Conky konfigracij...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="188"/>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="190"/>
        <source>Configure conky search paths</source>
        <translation>Nastavi poti za iskanje conkijev</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="192"/>
        <source>Refresh</source>
        <translation>Osveži</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="194"/>
        <source>Refresh conky list</source>
        <translation>Osveži seznam conkijev</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="196"/>
        <source>Start All</source>
        <translation>Zaženi vse</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="198"/>
        <source>Start all enabled conkies</source>
        <translation>Zaženi vse izbrane conkije</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="200"/>
        <source>Stop All</source>
        <translation>Zaustavi vse</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="202"/>
        <source>Stop all running conkies</source>
        <translation>zaustavi vse zagnane conkije</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="951"/>
        <location filename="../src/mainwindow.cpp" line="995"/>
        <source>Running</source>
        <translation>Se izvaja</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="953"/>
        <location filename="../src/mainwindow.cpp" line="996"/>
        <source>Stopped</source>
        <translation>Zaustavljeno</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="210"/>
        <source>Search conky by name...</source>
        <translation>Iskanje conkija po imenu...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="212"/>
        <source>Search conkies by name (Ctrl+F)</source>
        <translation>Pošči Conky po imenu (Crtl+F)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Display help</source>
        <translation>Prikaži pomoč</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="433"/>
        <location filename="../src/mainwindow.cpp" line="607"/>
        <source>Copy Conky</source>
        <translation>Kopiraj Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="479"/>
        <location filename="../src/mainwindow.cpp" line="655"/>
        <source>Conky Copied</source>
        <translation>Conky je skopiran</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="480"/>
        <source>Conky has been copied to your personal folder for editing:
%1</source>
        <translation>Conky je bil prekopiran v osebno mapo za urejanje:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="482"/>
        <location filename="../src/mainwindow.cpp" line="658"/>
        <source>Copy Failed</source>
        <translation>Kopiranje ni uspelo</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="482"/>
        <location filename="../src/mainwindow.cpp" line="658"/>
        <source>Failed to copy conky to your personal folder.</source>
        <translation>Conkija ni bilo mogoče kopirati v osebno mapo.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="544"/>
        <source>Delete Conky</source>
        <translation>Izbriši Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="656"/>
        <source>Conky has been copied to your personal folder for customization:
%1</source>
        <translation>Conky je bil prekopiran v osebno mapo za prilagajnje:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="184"/>
        <source>Previews</source>
        <translation>Predogled</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="186"/>
        <source>Generate preview images for conkies</source>
        <translation>Ustvari slike za predogled conkijev</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="206"/>
        <location filename="../src/mainwindow.cpp" line="467"/>
        <location filename="../src/mainwindow.cpp" line="643"/>
        <location filename="../src/mainwindow.cpp" line="949"/>
        <location filename="../src/mainwindow.cpp" line="994"/>
        <source>All</source>
        <translation>Vse</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="207"/>
        <source>Filter conkies by running status or location</source>
        <translation>Filtriraj conkije glede na stanje zagona ali lokacijo</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="429"/>
        <location filename="../src/mainwindow.cpp" line="603"/>
        <source>Enter a name for the copy:</source>
        <translation>Vnesite ime za kopijo:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="430"/>
        <location filename="../src/mainwindow.cpp" line="604"/>
        <source>In order for you to edit and save a conky, it must first be copied to ~/.conky where you have permission.
Enter a name for the copy.</source>
        <translation>Za urejanje in shranjevanje conkijev jih je potrebno najprej prekopirati v  ~/.conky, kjer morate imeti pravice.
Vnesite ime kopiije.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="447"/>
        <location filename="../src/mainwindow.cpp" line="623"/>
        <source>Directory Exists</source>
        <translation>Mapa obstaja</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="448"/>
        <location filename="../src/mainwindow.cpp" line="624"/>
        <source>A conky with the name '%1' already exists in your personal folder.
Do you want to overwrite it?</source>
        <translation>Conky z imenom &quot;%1&quot; že obstaja v osebni mapi.
Ga želite prepisati?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="515"/>
        <source>Edit Conky</source>
        <translation>Uredi Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="516"/>
        <source>This conky file is read-only and requires administrator privileges to edit.
Do you want to edit it with elevated privileges?</source>
        <translation>Ta conky je zgolj za branje in za urejanje potrebuje skrbniške pravice.
Ali želite urejanje s povečanimi pravicami?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="545"/>
        <source>Are you sure you want to delete the conky file:
%1

This action cannot be undone.</source>
        <translation>Ali želite izbrisati conky datoteko:
%1

Tega dejanja ni mogoče razveljaviti.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="577"/>
        <source>Delete Failed</source>
        <translation>Brisanje ni uspelo</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="577"/>
        <source>Failed to delete conky file:
%1</source>
        <translation>Conky datoteke
%1
ni bilo mogoče izbrisati</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="665"/>
        <source>Customize Conky</source>
        <translation>Prilagodi Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="666"/>
        <source>This conky file is read-only and requires administrator privileges to customize.
Do you want to customize it with elevated privileges?</source>
        <translation>Ta conky je zgolj za branje in za prilagajnje potrebuje skrbniške pravice.
Ali ga želite prilagajati s povečanimi pravicami?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="838"/>
        <source>Editor Error</source>
        <translation>Napaka urejevalnika</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="838"/>
        <source>Cannot start editor for file: %1</source>
        <translation>Ne morem zagnati urejevalnnika za datoteko: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="848"/>
        <source>About MX Conky</source>
        <translation>O MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="850"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="851"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>Grafični vmesnik za konfiguriranje Conkyja v MX Linuxu</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="854"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Avtorska zaščita (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="855"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="856"/>
        <location filename="../src/mainwindow.cpp" line="868"/>
        <source>Changelog</source>
        <translation>Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="857"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="879"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="910"/>
        <source>MX Conky Help</source>
        <translation>Pomoč za MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="955"/>
        <location filename="../src/mainwindow.cpp" line="997"/>
        <source>Autostart</source>
        <translation>Samodejni zagon</translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <location filename="../src/previewdialog.cpp" line="50"/>
        <source>Generate Preview</source>
        <translation>Ustvari predogled</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="75"/>
        <source>Generate preview images for</source>
        <translation>Ustvari predogledne slike za</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="78"/>
        <source>Selected Widget</source>
        <translation>Izbrani gradniki</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="79"/>
        <source>All Widgets with Missing Previews</source>
        <translation>Vsi gradniki brez predogledov</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="80"/>
        <source>All Widgets (Overwrite Existing Images)</source>
        <translation>Vsi gradniki (prepiši obstoječe slike)</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="85"/>
        <source>No conky is currently selected</source>
        <translation>Trenutno ni izbran noben conky</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="93"/>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="96"/>
        <source>High quality images (PNG)</source>
        <translation>Visokokakovostne slike (PNG)</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="97"/>
        <source>Generate preview images in PNG format instead of JPEG</source>
        <translation>Slike za predogled ustvari v PNG zapisu namesto JPEG</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="114"/>
        <source>OK</source>
        <translation>V redu</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="118"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No Items</source>
        <translation>Ni predmetov</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No conky widgets need preview generation.</source>
        <translation>Noben conky gradnik ne rabi generiranja predogleda.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="151"/>
        <source>Missing Dependency</source>
        <translation>Manjkajoča odvisnost</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="152"/>
        <source>Preview generation requires the GraphicsMagick compatibility tools.
Please install the graphicsmagick-imagemagick-compat package to enable this feature.</source>
        <translation>Za ustvarjanje predogledov so potrebna orodja za združljivost GraphicsMagick.
Namestite paket graphicsmagick-imagemagick-compat, da ji omogočite.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="163"/>
        <source>Starting preview generation...</source>
        <translation>Zagon ustvarjanja predogledov...</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="167"/>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="206"/>
        <source>Generating preview for: %1</source>
        <translation>Ustvarjanje predogleda za: %1</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="427"/>
        <source>Preview generation complete! Generated %1 previews.</source>
        <translation>Ustvarjanje predogledov je bilo zaključeno! Število ustvarjenih predogledov je %1.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="431"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="434"/>
        <source>Preview Generation Complete</source>
        <translation>Ustvarjanje predogledov je končano</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="435"/>
        <source>Successfully generated %1 preview images.</source>
        <translation>Uspešno število ustvarjenih slik za predogled je %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="67"/>
        <source>Select Conky Manager config file</source>
        <translation>Izberi konfiguracijsko datoteko za Conky upravljalnik</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>You must run this program as normal user</source>
        <translation>Ta program morate zagnati kot navaden uporabnik</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/settingsdialog.cpp" line="40"/>
        <location filename="../src/settingsdialog.cpp" line="62"/>
        <source>Select Conky Directory</source>
        <translation>Izberite Conky mapo</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="83"/>
        <source>MX Conky Settings</source>
        <translation>MX Conky nastavitve </translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="91"/>
        <source>Search Paths</source>
        <translation>Poti iskanja</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="92"/>
        <source>Autostart</source>
        <translation>Samodejni zagon</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="167"/>
        <source>Conky Search Paths</source>
        <translation>Conky poti iskanja</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="173"/>
        <source>Add Path</source>
        <translation>Dodaj pot</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="176"/>
        <source>Remove Path</source>
        <translation>Odstrani pot</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="179"/>
        <source>Edit Path</source>
        <translation>Uredi pot</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="206"/>
        <source>Autostart Settings</source>
        <translation>Nastavitve samodejnega zagona</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="209"/>
        <source>Start conky at system startup</source>
        <translation>Zaženi Conky ob zagonu sistema</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="212"/>
        <source>Startup delay (seconds):</source>
        <translation>Zamik ob zagonu (v sekundah):</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="95"/>
        <source>OK</source>
        <translation>V redu</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="96"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
</context>
</TS>